#pragma NOIV               // Do not generate interrupt vectors
//-----------------------------------------------------------------------------
//   File:      CYStream.c
//   Contents:   USB Bulk and Isoc streaming example code.
//
// Copyright (c) 2011, Cypress Semiconductor Corporation All rights reserved
//
// This software is owned by Cypress Semiconductor Corporation
// (Cypress) and is protected by United States copyright laws and
// international treaty provisions.  Therefore, unless otherwise specified in a
// separate license agreement, you must treat this
// software like any other copyrighted material.  Reproduction, modification, translation,
// compilation, or representation of this software in any other form
// (e.g., paper, magnetic, optical, silicon, etc.) is prohibited
// without the express written permission of Cypress.
//
// Disclaimer: Cypress makes no warranty of any kind, express or implied, with
// regard to this material, including, but not limited to, the implied warranties
// of merchantability and fitness for a particular purpose. Cypress reserves the
// right to make changes without further notice to the materials described
// herein. Cypress does not assume any liability arising out of the application
// or use of any product or circuit described herein. Cypress products described
// herein are not authorized for use as components in life-support devices.
//
// This software is protected by and subject to worldwide patent
// coverage, including U.S. and foreign patents. Use may be limited by
// and subject to the Cypress Software License Agreement.
//
//-----------------------------------------------------------------------------
#include "fx2.h"
#include "fx2regs.h"
#include "fx2sdly.h"            // SYNCDELAY macro

extern BOOL   GotSUD;         // Received setup data flag
extern BOOL   Sleep;
extern BOOL   Rwuen;
extern BOOL   Selfpwr;

#define GPIFTRIGRD 4
#define GPIF_EP2 0

#define SetADCSpeed 0xB0	//Request code to controll the Port A 0 pin to set the ADC speed
#define SetIntExtCLK 0xB1	//Request code to controll the usage of the Internal or External Clock

#define SetACDC 0xB5 		//Request code (Controll Endpoint)	
#define SetAtten 0xB6 		//Request code (Controll Endpo
#define SetGain 0xB7 		//Request code (Controll Endpoint)	int)	


#define SetOffs 0xBC 		//Request code (Controll Endpoint)
#define SetFreq 0xBB 		//Request code (Controll Endpoint) - idea to controll external DDS over SPI
#define SetWaveForm 0xBA	//Request code (Controll Endpoint) - idea to controll external DDS over SPI
//Define the SPI pins

enum {	// Alternate Serttings for HIGH speed operation
    Alt0_BulkIN = 0
};


BYTE    Configuration;      // Current configuration
BYTE    AlternateSetting = Alt0_BulkIN;   // Alternate settings

int AD9833_control_reg;			//Controll register for AD9833 DDS

//Define the SPI pins	(using bit adressing)
sbit MOSI = IOA ^ 7;
sbit SPI_CLK = IOA ^ 6;
sbit CS_AD9833= IOA ^ 5;
sbit CS_DDS_OFFS_Pot= IOA ^ 4;

//Define relay pins
sbit Preamp_Gain= IOA ^ 3;
sbit Preamp_Atten= IOA ^ 2;
sbit AC_DC= IOA ^ 1;

sbit ADC_Speed = IOA ^ 0;		//Pin determining the ADC clock speed (connect the pin directrly to RDY0 (GPIF takes care))

//************ Prototypes *********************
void GpifInit ();
void SPIByteWrite(unsigned char b);
void AD9833init(void);
void write_reg(int data_to_send);


//-----------------------------------------------------------------------------
// Task Dispatcher hooks
//   The following hooks are called by the task dispatcher.
//-----------------------------------------------------------------------------

void TD_Init(void)             // Called once at startup
{
   int j;

   // set the CPU clock to 48MHz
   CPUCS = ((CPUCS & ~bmCLKSPD)| bmCLKSPD1);
   SYNCDELAY;


   // set the slave FIFO interface to 48MHz
   IFCONFIG |= 0x40;
   SYNCDELAY;

    // Default interface uses endpoint 2, zero the valid bit on all others
    // Just using endpoint 2, zero the valid bit on all others
    EP2CFG = 0xE0;  // EP2 is DIR=IN, TYPE=BULK, SIZE=512, BUF=4x
	SYNCDELAY;

	
	
	/////////////////////////////////

	// out endpoints do not come up armed

 	FIFORESET = 0x80;  // set NAKALL bit to NAK all transfers from host
  	SYNCDELAY;
  	FIFORESET = 0x02;  // reset EP2 FIFO
  	SYNCDELAY;

  	FIFORESET = 0x00;  // clear NAKALL bit to resume normal operation
  	SYNCDELAY;

  	
  	EP6FIFOCFG = 0x11; // auto out mode, disable PKTEND zero length send, byte ops
  	SYNCDELAY;
  	EP2FIFOCFG = 0x09; // auto in mode, disable PKTEND zero length send, byte ops
  	SYNCDELAY; 
	/////////////////////////////////

  	AUTOPTRSETUP |= 0x01;

   // We want to get SOF interrupts
   USBIE |= bmSOF;
   
  // Prepare data (for test pourpous)
      for (j=0;j<512;j++)
      {
	  	  EP2FIFOBUF[j] = 0xAA;
  //       EP2FIFOBUF[j] = (BYTE)j;
      }

//Enable Port A as output 
	PORTACFG = 0x00;	// PORTA is is configured as an I/O
  	OEA = 0xFF;		//PORTA is is configured as an Output
	
//Set initial state of the relays
	Preamp_Gain = 0;	
	Preamp_Atten = 0;
	AC_DC = 0;

	CS_DDS_OFFS_Pot=1;	// Set CS of the digital pot for DDS offset high
	
    EP2BCH = 0x02;
    EP2BCL = 0x00;
	
	
	GpifInit();
	IFCONFIG &= ~0x20;		//Set IFCLK as input (to be able to acept external clock)

//*********** GPIF i setting external clock but here manualu retun to internal ************
//********** to ensure stable connetion with the PC and default is high speed aquasation *****
//********** external clock isusd only with low speed aqusation (16MHz external clock)

// set the slave FIFO interface to 48MHz
   	IFCONFIG |= 0x40;				//Set 48Mhz 
	IFCONFIG |= 0x80;				//Set Internal Clock
	
	
	AD9833init();					//Initialize the DDS

    Rwuen = TRUE;                 // Enable remote-wakeup
}

void TD_Poll(void)             // Called repeatedly while the device is idle
{  
	if( EZUSB_HIGHSPEED( ) )
	{ 
	    // Perform USB activity based upon the Alt. Interface selected 
	     switch (AlternateSetting)
	    {
	        case Alt0_BulkIN:
	            // Send data on EP2
	            while(!(EP2468STAT & bmEP2FULL))
	            {
				if( GPIFTRIG & 0x80 )                      // if GPIF interface IDLE
        			{
 //        			 if( !( EP24FIFOFLGS & 0x01 ) )           // if EP2 FIFO is not full
 //         				{
						GPIFTCB1 = 0x02;   // set GPIF transaction count to 512, since  
                          // GPIFADR can only access 512                	
		    			GPIFTCB0 = 0x00;
			 //   		SYNCDELAY;
			    	
						
						GPIFTRIG = GPIFTRIGRD | GPIF_EP2; // launch GPIF FIFO READ Transaction to EP2IN
     
						
						GPIFADRH = 0x00;            // handles full-speed case and high-speed case
		      			GPIFADRL = 0x00;            // reset GPIFADR[8:0] to access the next bank at offset 0

	               	 	EP2BCH = 0x02;
	                	EP2BCL = 0x00;
			
//						}		
		      			
	              }
	            }
			

	        break;
	
	   }
	   
	}
}




BOOL TD_Suspend(void)          // Called before the device goes into suspend mode
{
   return(TRUE);
}

BOOL TD_Resume(void)          // Called after the device resumes
{
   return(TRUE);
}

//-----------------------------------------------------------------------------
// Device Request hooks
//   The following hooks are called by the end point 0 device request parser.
//-----------------------------------------------------------------------------

BOOL DR_GetDescriptor(void)
{
   return(TRUE);
}

BOOL DR_SetConfiguration(void)   // Called when a Set Configuration command is received
{
   SYNCDELAY;                   
   EP2AUTOINLENH = 0x02;       // set AUTOIN commit length to 512 bytes
   SYNCDELAY;                  
   EP2AUTOINLENL = 0x00;
   SYNCDELAY;
            	
   Configuration = SETUPDAT[2];
   return(TRUE);            // Handled by user code
}

BOOL DR_GetConfiguration(void)   // Called when a Get Configuration command is received
{
   EP0BUF[0] = Configuration;
   EP0BCH = 0;
   EP0BCL = 1;
   return(TRUE);            // Handled by user code
}

BOOL DR_SetInterface(void)       // Called when a Set Interface command is received
{
    BYTE	updateDisplay = TRUE;
    AlternateSetting = SETUPDAT[2];

	// ...FX2 in high speed mode
	if( EZUSB_HIGHSPEED( ) )
	{ 
	    // Change configuration based upon the Alt. Interface selected 
	    switch (AlternateSetting)
	    {
	        case Alt0_BulkIN:
	            // Only using endpoint 2, zero the valid bit on all others
	            // Just using endpoint 2, zero the valid bit on all others
	            EP2CFG = 0xE0;  // EP2 is DIR=IN, TYPE=BULK, SIZE=512, BUF=4x
	            SYNCDELAY;
	
	            EP1OUTCFG = (EP1OUTCFG & 0x7F);
	        	SYNCDELAY;
	        	EP1INCFG = (EP1INCFG & 0x7F);
	        	SYNCDELAY;
	        	EP4CFG = (EP4CFG & 0x7F);
	        	SYNCDELAY;
	        	EP6CFG = (EP6CFG & 0x7F);
	        	SYNCDELAY;
	        	EP8CFG = (EP8CFG & 0x7F);
	        	SYNCDELAY;
	
	            // Clear out any committed packets
	            FIFORESET = 0x80;
	            SYNCDELAY;
	            FIFORESET = 0x02;
	            SYNCDELAY;
	            FIFORESET = 0x00;
	            SYNCDELAY;
	
	            // Reset data toggle to 0
	            TOGCTL = 0x12;  // EP2 IN
	            TOGCTL = 0x32;  // EP2 IN Reset
	
	        break;       
	    }
	}  

   return(TRUE);            // Handled by user code
}

BOOL DR_GetInterface(void)       // Called when a Set Interface command is received
{
   EP0BUF[0] = AlternateSetting;
   EP0BCH = 0;
   EP0BCL = 1;
   return(TRUE);            // Handled by user code
}

BOOL DR_GetStatus(void)
{
   return(TRUE);
}

BOOL DR_ClearFeature(void)
{
   return(TRUE);
}

BOOL DR_SetFeature(void)
{
   return(TRUE);
}

BOOL DR_VendorCmnd(void)
{
	switch (SETUPDAT[1])
  		{
		case SetADCSpeed:
			if(SETUPDAT[2] == 1)
				ADC_Speed = 0;
			else 
				ADC_Speed = 1;
		break;


		case SetIntExtCLK:
			if(SETUPDAT[2] == 1)
				IFCONFIG |= 0x80;				//Set Internal Clock
				
			else 
				IFCONFIG &= ~0x80;				//Set External Clock
		break;
		

		case SetACDC:	
			
 			if(SETUPDAT[2] == 1)
				AC_DC = 1;	//Set AC
			else
				AC_DC = 0;	//Set DC

   		break;

		case SetAtten:	
			
 			if(SETUPDAT[2] == 1)
				Preamp_Atten = 1;	//Set 1:5 attenuation
			else
				Preamp_Atten = 0;	//Set 1:1 attenuation	

   		break;

		case SetGain:	
			
 			if(SETUPDAT[2] == 1)
				Preamp_Gain = 1;	//Set Set gain 10
			else
				Preamp_Gain = 0;	//Set gain 1 

   		break;

		case SetFreq:
			write_reg(0x4000 | (0x3FFF & ((SETUPDAT[3]<<8) + SETUPDAT[2])));                           // FREQ0, data_0 (wValue) - don't pass valure biger than 0x3FF (14Bit)
			write_reg(0x4000 | (0x3FFF &((SETUPDAT[5]<<8) + SETUPDAT[4])));                            // FREQ0, data_1 (wIndex) - don't pass valure biger than 0x3FF (14Bit)
			write_reg(0xC000);                           // PHASE0
			//SPIByteWrite(0xAA);		
		break;
		
		case SetWaveForm:
			switch (SETUPDAT[2])
				{
				case 0:
					AD9833_control_reg &= 0xFFDD;
				break;

				case 1:
					AD9833_control_reg &= 0xFFDF;
					AD9833_control_reg |= 0x02;
				break;

				case 2:
					AD9833_control_reg &= 0xFFFD;
					AD9833_control_reg |= 0x28;
				break;
					
				default:
     				return(TRUE);
				}
			
			write_reg(AD9833_control_reg);		
		break;

		case SetOffs:
			CS_DDS_OFFS_Pot=0;
			SPIByteWrite(SETUPDAT[2]);
			CS_DDS_OFFS_Pot=1;

		break;

	 	default:
     		return(TRUE);
     }
    return(FALSE);

}
//AD9833 Functions

void AD9833init(void) 
{
  SPI_CLK = 1;
  CS_AD9833= 1;

  write_reg(0x0100);                           // reset (RESET:1)
  write_reg(0x2100);                           // control (B28:1, HLB:0)
  AD9833_control_reg = 0x2000;                        // default: DAC powered up, Internal clock enabled, sine
  write_reg(AD9833_control_reg);
}


//SPI Functions.......................

void write_reg(WORD data_to_send)
{
  SPI_CLK = 1;
  CS_AD9833= 0;
  SPIByteWrite(data_to_send >> 8);    // high byte
  SPIByteWrite(data_to_send & 0xFF);  // low byte
  CS_AD9833= 1;
}

void SPIByteWrite(unsigned char b)
// caller manages SPI_CS signal
{	
	SPI_CLK = 1;
	if(b & 0x80)	MOSI = 1; 
	else	MOSI= 0;

	SPI_CLK = 0;  
	SPI_CLK = 1;
	
	if(b & 0x40)	MOSI = 1;
	else	MOSI=0;
	
	SPI_CLK = 0;  
	SPI_CLK = 1;
	
	if(b & 0x20)	MOSI = 1;
	else	MOSI= 0;
	
	SPI_CLK = 0;  
	SPI_CLK = 1;
	
	if(b & 0x10)	MOSI = 1;
	else	MOSI= 0;
	
	SPI_CLK = 0;  
	SPI_CLK = 1;
	
	if(b & 0x08)	MOSI = 1;
	else	MOSI= 0;
	
	SPI_CLK = 0;  
	SPI_CLK = 1;
	
	if(b & 0x04)	MOSI = 1;
	else	MOSI= 0;
	
	SPI_CLK = 0;  
	SPI_CLK = 1;
	
	if(b & 0x02)	MOSI = 1;
	else	MOSI= 0;
	
	SPI_CLK = 0;  
	SPI_CLK = 1;
	
	if(b & 0x01)	MOSI = 1;
	else	MOSI= 0;
	
	SPI_CLK = 0;  
	SPI_CLK = 1;
}


//-----------------------------------------------------------------------------
// USB Interrupt Handlers
//   The following functions are called by the USB interrupt jump table.
//-----------------------------------------------------------------------------

// Setup Data Available Interrupt Handler
void ISR_Sudav(void) interrupt 0
{
   GotSUD = TRUE;            // Set flag
   EZUSB_IRQ_CLEAR();
   USBIRQ = bmSUDAV;         // Clear SUDAV IRQ
}

// Setup Token Interrupt Handler
void ISR_Sutok(void) interrupt 0
{
   EZUSB_IRQ_CLEAR();
   USBIRQ = bmSUTOK;         // Clear SUTOK IRQ
}

void ISR_Sof(void) interrupt 0
{
   	EZUSB_IRQ_CLEAR();
   	USBIRQ = bmSOF;            // Clear SOF IRQ
}

void ISR_Ures(void) interrupt 0
{
	// Whenever we get a USB Reset, we should revert to full speed mode
    pConfigDscr = pFullSpeedConfigDscr;
    ((CONFIGDSCR xdata *) pConfigDscr)->type = CONFIG_DSCR;
    pOtherConfigDscr = pHighSpeedConfigDscr;
    ((CONFIGDSCR xdata *) pOtherConfigDscr)->type = OTHERSPEED_DSCR;
   
   EZUSB_IRQ_CLEAR();
   USBIRQ = bmURES;         // Clear URES IRQ

}

void ISR_Susp(void) interrupt 0
{
   Sleep = TRUE;
   EZUSB_IRQ_CLEAR();
   USBIRQ = bmSUSP;
}

void ISR_Highspeed(void) interrupt 0
{
   if (EZUSB_HIGHSPEED())
   {
      pConfigDscr = pHighSpeedConfigDscr;
      ((CONFIGDSCR xdata *) pConfigDscr)->type = CONFIG_DSCR;
      pOtherConfigDscr = pFullSpeedConfigDscr;
      ((CONFIGDSCR xdata *) pOtherConfigDscr)->type = OTHERSPEED_DSCR;

      // This register sets the number of Isoc packets to send per
      // uFrame.  This register is only valid in high speed.
//      EP2ISOINPKTS = 0x03;
      EP2ISOINPKTS = 0x83;	// 3 packets per microframe, AADJ=1
	  
   }
   else
   {
      pConfigDscr = pFullSpeedConfigDscr;
      pOtherConfigDscr = pHighSpeedConfigDscr;
   }

   EZUSB_IRQ_CLEAR();
   USBIRQ = bmHSGRANT;
}
void ISR_Ep0ack(void) interrupt 0
{
}
void ISR_Stub(void) interrupt 0
{
}
void ISR_Ep0in(void) interrupt 0
{
}
void ISR_Ep0out(void) interrupt 0
{
}
void ISR_Ep1in(void) interrupt 0
{
}
void ISR_Ep1out(void) interrupt 0
{
}

// ISR_Ep2inout is called on every OUT packet receieved.
// We don't do anything with the data.  We just indicate we are done with the buffer.
void ISR_Ep2inout(void) interrupt 0
{
}
void ISR_Ep4inout(void) interrupt 0
{
}
void ISR_Ep6inout(void) interrupt 0
{
}
void ISR_Ep8inout(void) interrupt 0
{
}
void ISR_Ibn(void) interrupt 0
{
	 
}
void ISR_Ep0pingnak(void) interrupt 0
{
}
void ISR_Ep1pingnak(void) interrupt 0
{
}
void ISR_Ep2pingnak(void) interrupt 0
{
}
void ISR_Ep4pingnak(void) interrupt 0
{
}
void ISR_Ep6pingnak(void) interrupt 0
{
}
void ISR_Ep8pingnak(void) interrupt 0
{
}
void ISR_Errorlimit(void) interrupt 0
{
}
void ISR_Ep2piderror(void) interrupt 0
{
}
void ISR_Ep4piderror(void) interrupt 0
{
}
void ISR_Ep6piderror(void) interrupt 0
{
}
void ISR_Ep8piderror(void) interrupt 0
{
}
void ISR_Ep2pflag(void) interrupt 0
{
}
void ISR_Ep4pflag(void) interrupt 0
{
}
void ISR_Ep6pflag(void) interrupt 0
{
}
void ISR_Ep8pflag(void) interrupt 0
{
}
void ISR_Ep2eflag(void) interrupt 0
{
}
void ISR_Ep4eflag(void) interrupt 0
{
}
void ISR_Ep6eflag(void) interrupt 0
{
}
void ISR_Ep8eflag(void) interrupt 0
{
}
void ISR_Ep2fflag(void) interrupt 0
{
}
void ISR_Ep4fflag(void) interrupt 0
{
}
void ISR_Ep6fflag(void) interrupt 0
{
}
void ISR_Ep8fflag(void) interrupt 0
{
}
void ISR_GpifComplete(void) interrupt 0
{
}
void ISR_GpifWaveform(void) interrupt 0
{
}

